@@ -49,12 +49,8 @@ class MainWindow(object):
         self.tree.get_object('move_up_button').set_sensitive(False)
         self.tree.get_object('move_down_button').set_sensitive(False)
         self.tree.get_object('new_separator_button').set_sensitive(False)
-        accelgroup = Gtk.AccelGroup()
-        keyval, modifier = Gtk.accelerator_parse('F1')
-        accelgroup.connect(keyval, modifier, Gtk.AccelFlags.VISIBLE, self.on_help_button_clicked)
 
         self.main_window = self.tree.get_object('mainwindow')
-        self.main_window.add_accel_group(accelgroup)
 
         self.editor = None
 
@@ -243,11 +239,19 @@ class MainWindow(object):
             menu_tree.get_selection().select_path((0,))
         else:
             parent = menus[iter][2]
-        file_path = os.path.join(util.getUserDirectoryPath(), util.getUniqueFileId('alacarte-made', '.directory'))
+	file_name = util.getUniqueFileId('alacarte-made', '.directory')
+        file_path = os.path.join(util.getUserDirectoryPath(), file_name)
 
         editor = DirectoryEditor(self.main_window, file_path)
+        editor.file_name = file_name;
+        editor.parent = parent.get_menu_id()
+        editor.connect ('response', self.on_directory_created)
         editor.run()
 
+    def on_directory_created(self, editor, response):
+        if response == True:
+            self.editor.insertExternalMenu(editor.file_name, editor.parent)
+
     def on_new_item_button_clicked(self, button):
         menu_tree = self.tree.get_object('menu_tree')
         menus, iter = menu_tree.get_selection().get_selected()
@@ -257,11 +261,19 @@ class MainWindow(object):
             menu_tree.get_selection().select_path((0,))
         else:
             parent = menus[iter][2]
-        file_path = os.path.join(util.getUserItemPath(), util.getUniqueFileId('alacarte-made', '.desktop'))
+        file_name = util.getUniqueFileId('alacarte-made', '.desktop')
+        file_path = os.path.join(util.getUserItemPath(), file_name)
 
         editor = LauncherEditor(self.main_window, file_path)
+        editor.file_name = file_name;
+        editor.parent = parent.get_menu_id()
+        editor.connect ('response', self.on_item_created)
         editor.run()
 
+    def on_item_created(self, editor, response):
+        if response == True:
+            self.editor.insertExternalItem(editor.file_name, editor.parent)
+
     def on_new_separator_button_clicked(self, button):
         item_tree = self.tree.get_object('item_tree')
         items, iter = item_tree.get_selection().get_selected()
@@ -427,9 +439,6 @@ class MainWindow(object):
         after = items[path][3]
         self.editor.moveItem(item.get_parent(), item, after=after)
 
-    def on_help_button_clicked(self, *args):
-        Gtk.show_uri(Gdk.Screen.get_default(), "ghelp:user-guide#menu-editor", Gtk.get_current_event_time())
-
     def on_restore_button_clicked(self, button):
         self.editor.restoreToSystem()
 
